==> aiootp-0.23.8.tar.gz: aiootp-0.23.8/CODE_OF_CONDUCT.md <==

# Short Norms

No intentional oppression.

Assume best intentions.

Make space, take space – Be aware of the space you’re taking up.

Act in solidarity, not charity.

Treat each other with respect.

Yes to passion. No to obligation.

Ask for support if you need it. Offer support if you can.

All contribution suggestions are welcome.

We strive for full inclusion.

We value feedback.

Dissent and questions are a gift to the group.

Vulnerability and emotions are supported.




# Equitible Spaces Norms

- No intentional, unchallenged perpetuations of racism, sexism, transphobia, ableism, classism, or any other harmful / supremacist power structures will be tolerated.
- We defer to each person to decide for themselves whether an action impacted them negatively. We support finding resolutions which prevent repeated harms and abuse. Verbal, physical, and/or sexual assault won't be tolerated.
- Mistakes are human; assume best intentions. We're all on journeys reconciling our ideals with the harmful behaviors, language, and states of the world which shape us. Microaggressions and other slip-ups will either be called-in as small-group teachable moments, or as publicly as is appropriate given the context and scope of the behavior/language to be addressed.
- We act in solidarity, not charity, with marginalized groups and individuals. This group does not have a hierarchical view of intersections of oppression. We always defer to lived experience.
- We speak from our own experience. We don’t assume what other people are thinking or put words in other people’s mouths.
- If it would be helpful to the group to share someone else’s story, it's done anonymously unless their explicit consent is given to share identifying details. Not everyone will want to share their stories and that is okay.
- Mutual support is essential, but please ask first if you need emotional labor. We respect each other and, in the name of voluntary relations, emotional labor will be respected.
- We're a horizontally-organized collective. No one has a higher rank than anyone else, and we treat each other with the respect of equals.
- For specific projects or actions we may designate conveners or point people. Their role is to simply convene the group, ensure that things move forward, and to be a point of contact. They should have no more power than anyone else.
- We practice active and reflective listening — listening to each other completely and with intent to understand, rather than listening simply to respond. And reflecting back what we heard to ensure that we heard correctly.
- We respect that people have different communication styles and needs.
- If someone isn't following these norms, we talk with them about it promptly, directly, and compassionately. We can utilize our conflict resolution process if needed.

We stand in solidarity with the activist community as a whole: all who work towards the common goal of creating a better, more equitable world.


## A General Process for Navigating Difficult Situations

Sometimes things don’t fit or are too complex for the normal conflict resolution process. This could be due to the nature of the situation, the number of people involved, the length of time it was unaddressed, or a combination of many factors. In those cases we will invite those involved to develop a custom process that fits the needs of the situation.


#### Principles for This Process:

In addition to the conflict resolution principles, these are especially important:

- Consent — Nothing will happen without the consent of all those involved (including those supporting the conversation). We will check in about every decision and small step along the way.
- Slow and steady — This will be a slow and steady process. It'll be slow because emotions can be difficult and take time to process, collective process takes time. The process will move forward steadily. The situation probably didn't start in a day, it may not be addressed in a day either.


#### The Process:

We'll discuss with those involved about what they’d like to do. It could potentially be part conflict resolution, part community accountability, and part restorative justice. At least two members of the community will observe the process with the goal of equitable resolutions. The exact process will be fluid and decided by those involved. We really don’t know what it will look like. Decisions could be made by the group of those involved or negotiated through observers. If individuals are in conflict, they won't necessarily have to speak to each other directly. All decisions will be consensual.


#### Basic process steps:

1. We establish some basic norms and boundaries for the process.
2. We discuss goals for the process so we know where we're trying to go.
3. We develop a plan for how the process will go. This will involve hearing from all sides about what they'd like to see happen and negotiating a plan that all are happy with. (The plan could include a series of one-on-one conversations, a larger community meeting or meetings, finding an outside mediator or other support, or anything else people agree to.)
4. We implement the plan. Continually checking on how it’s going, revising norms, and revising the plan (consensually) to accomplish our goals.

==> aiootp-0.23.9.tar.gz: aiootp-0.23.9/CODE_OF_CONDUCT.md <==

# Short Norms

No intentional oppression.

Assume best intentions.

Make space, take space – Be aware of the space you’re taking up.

Act in solidarity, not charity.

Treat each other with respect.

Yes to passion. No to obligation.

Ask for assistance if you need it. Offer assistance if you can.

All contribution suggestions are welcome.

We strive for full inclusion.

We value feedback.

Dissent and questions are a gift to the group.

Vulnerability and emotions are cherished.




# Equitible Spaces Norms

- No intentional, unchallenged perpetuations of racism, sexism, transphobia, ableism, classism, or any other harmful / supremacist power structures will be tolerated.
- We defer to each person to decide for themselves whether an action impacted them negatively. We support finding resolutions which prevent repeated harms and abuse. Verbal, physical, and/or sexual assault won't be tolerated.
- Mistakes are human; assume best intentions. We're all on journeys reconciling our ideals with the harmful behaviors, language, and states of the world which shape us. Microaggressions and other slip-ups will either be called-in as small-group teachable moments, or as publicly as is appropriate given the context and scope of the behavior/language to be addressed.
- We act in solidarity, not charity, with marginalized groups and individuals. This group does not have a hierarchical view of intersections of oppression. We always defer to lived experience.
- We speak from our own experience. We don’t assume what other people are thinking or put words in other people’s mouths.
- If it would be helpful to the group to share someone else’s story, it's done anonymously unless their explicit consent is given to share identifying details. Not everyone will want to share their stories and that is okay.
- Mutual-aid is essential, but please ask first if you need emotional labor. We respect each other and, in the name of voluntary relations, emotional labor will be respected.
- We're a horizontally-organized collective. No one has a higher rank than anyone else, and we treat each other with the respect of equals.
- For specific projects or actions we may designate conveners or point people. Their role is to simply convene the group, ensure that things move forward, and to be a point of contact. They should have no more power than anyone else.
- We practice active and reflective listening — which is listening to each other completely and with intent to understand, rather than listening simply to respond — and reflecting back what we heard to ensure that we heard correctly.
- We respect that people have different communication styles and needs.
- If someone isn't following these norms, we talk with them about it promptly, directly, and compassionately. We can utilize our conflict resolution process if needed.

We stand in solidarity with the activist community as a whole: all who work towards the common goal of creating a better, more equitable world.


## A General Process for Navigating Difficult Situations

Sometimes things don’t fit or are too complex for the normal conflict resolution process. This could be due to the nature of the situation, the number of people involved, the length of time it was unaddressed, or a combination of many factors. In those cases we will invite those involved to develop a custom process that fits the needs of the situation.


#### Principles for This Process:

In addition to the conflict resolution principles, these are especially important:

- Consent — Nothing will happen without the consent of all those involved (including those backing the conversation). We will check in about every decision and small step along the way.
- Slow and steady — This will be a slow and steady process. It'll be slow because emotions can be difficult and take time to process, collective process takes time. The process will move forward steadily. The situation probably didn't start in a day, it may not be addressed in a day either.


#### The Process:

We'll discuss with those involved about what they’d like to do. It could potentially be part conflict resolution, part community accountability, and part restorative justice. At least two members of the community will observe the process with the goal of equitable resolutions. The exact process will be fluid and decided by those involved. We really don’t know what it will look like. Decisions could be made by the group of those involved or negotiated through observers. If individuals are in conflict, they won't necessarily have to speak to each other directly. All decisions will be consensual.


#### Basic process steps:

1. We establish some basic norms and boundaries for the process.
2. We discuss goals for the process so we know where we're trying to go.
3. We develop a plan for how the process will go. This will involve hearing from all sides about what they'd like to see happen and negotiating a plan that all are happy with. (The plan could include a series of one-on-one conversations, a larger community meeting or meetings, finding an outside mediator or other support, or anything else people agree to.)
4. We implement the plan. Continually checking on how it’s going, revising norms, and revising the plan (consensually) to accomplish our goals.
